# Changelog

All notable changes to this project will be documented in this file.

## 0.13.0 "Aquarius" - 1970-04-11 [YANKED]

Yanked due to issues with oxygen tanks, currently investigating

### Added

- Extra propellant in preparation for future versions

### Changed

- Replaced Ken Mattingly
- Stirred oxygen tanks

## 0.12.0 "Intrepid" - 1969-11-14

### Added

- New ALSEP package for surface science
- Color cameras
- Surface rendezvous with Surveyor 3

### Fixed

- 1201/1202 alarm distracting crew during landing

### Known Issues

- Lightning strike during launch: No effect on performance

## 0.11.0 "Eagle" - 1969-07-20

Initial stable release

### Changed

- Fully fueled lander to allow landing on the lunar surface